#include <stdio.h>
#include "ets_sys.h"
#include "osapi.h"
#include "user_interface.h"
#include "gpio.h"
#include "driver/uart.h"
#include "driver/i2c_master.h"

//------------------------------------------------------
#define LED 2
#define I2C_REQUEST_WRITE   0x00
#define I2C_REQUEST_READ    0x01
#define SLAVE_OWN_ADDRESS   0xA0
//------------------------------------------------------
uint8_t rd_value[20] = {0};
uint8_t wr_value[20] = {0x14,0x13,0x12,0x11,0x10,
                        0x0F,0x0E,0x0D,0x0C,0x0B,
                        0x0A,0x09,0x08,0x07,0x06,
                        0x05,0x04,0x03,0x02,0x01};
//------------------------------------------------------
void AT24C_WriteBytes (uint16_t addr,uint8_t *buf, uint16_t bytes_count)
{
  uint16_t i;
  uint8_t ack;
  i2c_master_start();
  i2c_master_writeByte(SLAVE_OWN_ADDRESS | I2C_REQUEST_WRITE);
  ack = i2c_master_checkAck();
  if(!ack)
  {
    os_printf("ADDR not ack\r\n");
  }
  i2c_master_writeByte((uint8_t) (addr>>8));
  i2c_master_send_ack();
  i2c_master_writeByte((uint8_t) addr);
  i2c_master_send_ack();
  for(i=0;i<bytes_count;i++)
  {
    i2c_master_writeByte(buf[i]);
    i2c_master_send_ack();
  }
  i2c_master_stop();

}
//------------------------------------------------------
void AT24C_ReadBytes (uint16_t addr, uint8_t *buf, uint16_t bytes_count)
{
  uint16_t i;
  uint8_t ack;
  i2c_master_start();
  i2c_master_writeByte(SLAVE_OWN_ADDRESS | I2C_REQUEST_WRITE);
  ack = i2c_master_checkAck();
  if(!ack)
  {
    os_printf("ADDR not ack\r\n");
  }
  i2c_master_writeByte((uint8_t) (addr>>8));
  i2c_master_send_ack();
  i2c_master_writeByte((uint8_t) addr);
  i2c_master_send_ack();
  i2c_master_start();
  i2c_master_writeByte(SLAVE_OWN_ADDRESS | I2C_REQUEST_READ);
  ack = i2c_master_checkAck();
  if(!ack)
  {
    os_printf("ADDR not ack\r\n");
  }
  for(i=0;i<bytes_count;i++)
  {
    buf[i] = i2c_master_readByte();
    if(i<(bytes_count-1)) i2c_master_send_ack();
    else  i2c_master_send_nack();
  }
  i2c_master_stop();
}
//------------------------------------------------------
uint32 ICACHE_FLASH_ATTR user_rf_cal_sector_set(void)
{
    enum flash_size_map size_map = system_get_flash_size_map();
    uint32 rf_cal_sec = 0;

    switch (size_map) {
        case FLASH_SIZE_4M_MAP_256_256:
            rf_cal_sec = 128 - 8;
            break;

        case FLASH_SIZE_8M_MAP_512_512:
            rf_cal_sec = 256 - 5;
            break;

        case FLASH_SIZE_16M_MAP_512_512:
        case FLASH_SIZE_16M_MAP_1024_1024:
            rf_cal_sec = 512 - 5;
            break;

        case FLASH_SIZE_32M_MAP_512_512:
        case FLASH_SIZE_32M_MAP_1024_1024:
            rf_cal_sec = 1024 - 5;
            break;

        default:
            rf_cal_sec = 0;
            break;
    }
    return rf_cal_sec;
}
//------------------------------------------------------
void ICACHE_FLASH_ATTR user_init()
{
  uint16_t i=0;
  // Configure the UART
  uart_init(BIT_RATE_115200, BIT_RATE_115200);
  gpio_init();
  i2c_master_gpio_init();
  ets_delay_us(100000);
  os_printf("\r\n");
  //AT24C_WriteBytes (0x032A, wr_value, 20);
  AT24C_ReadBytes(0x032A , rd_value, 20);
  for(i=0;i<20;i++)
  {
    //os_printf("%02X ",wr_value[i]);
    os_printf("%02X ",rd_value[i]);
  }
  os_printf("\r\n");
  while(1)
  {
    ets_delay_us(1000000);
    system_soft_wdt_feed();
    ets_delay_us(1000000);
    system_soft_wdt_feed();
  }
}
//------------------------------------------------------
